@@ -5,7 +5,7 @@
 ;; Author: J.D. Smith <jdtsmith@gmail.com>
 ;; URL: https://github.com/jdtsmith/kind-icon
 ;; Package-Requires: ((emacs "27.1") svg-lib)
-;; Version: 0.1.6
+;; Version: 0.1.7
 ;; Keywords: completion
 
 ;; kind-icon is free software: you can redistribute it
@@ -90,7 +90,7 @@ An vector of two alist for non-terminal and terminal.")
     (color "#" :icon "palette" :face success)
     (constant "co" :icon "lock-remove-outline" :face font-lock-constant-face)
     (constructor "cn" :icon "table-column-plus-after" :face font-lock-function-name-face)
-    (enum-member "em" :icon "format-list-checks" :face font-lock-builtin-face)
+    (enummember "em" :icon "format-list-checks" :face font-lock-builtin-face)
     (enum "e" :icon "format-list-bulleted-square" :face font-lock-builtin-face)
     (event "ev" :icon "lightning-bolt-outline" :face font-lock-warning-face)
     (field "fd" :icon "application-braces-outline" :face font-lock-variable-name-face)
@@ -111,7 +111,7 @@ An vector of two alist for non-terminal and terminal.")
     (string "s" :icon "sticker-text-outline" :face font-lock-string-face)
     (struct "%" :icon "code-braces" :face font-lock-variable-name-face)
     (text "tx" :icon "script-text-outline" :face shadow)
-    (type-parameter "tp" :icon "format-list-bulleted-type" :face font-lock-type-face)
+    (typeparameter "tp" :icon "format-list-bulleted-type" :face font-lock-type-face)
     (unit "u" :icon "ruler-square" :face shadow)
     (value "v" :icon "plus-circle-outline" :face font-lock-builtin-face)
     (variable "va" :icon "variable" :face font-lock-variable-name-face)
